package weather;

/**
 * Measured temperature data at a particular station on a particular day.
 * 
 * @author Prof. David Bernstein, James Madison University
 * 
 */
public class TemperatureObservation
{
  private double latitude, longitude;
  private double elevation;
  private int day, month, year;
  private double max, min;
  private String station, name;

  /**
   * Default Constructor.
   */
  private TemperatureObservation()
  {
    super();
  }

  /**
   * Populate this TemperatureObservation from a String representation.
   * 
   * @param line The String representation
   * @throws IllegalArgumentException if there is a problem
   */
  public void fromString(String line) throws IllegalArgumentException
  {
    String[] tokens = line.split("\t");
    if (tokens.length != 8) throw new IllegalArgumentException("Improper format.");
    
    station = tokens[0];
    name = tokens[1];
    
    try
    {
      latitude = Double.parseDouble(tokens[2]);
      longitude =  Double.parseDouble(tokens[3]);
      elevation = Double.parseDouble(tokens[4]);
      max = Double.parseDouble(tokens[6]);
      min = Double.parseDouble(tokens[7]);
    }
    catch (NumberFormatException nfe)
    {
      throw new IllegalArgumentException("Non-numeric data.");
    }
    
    String date[] = tokens[5].split("-");
    if (date.length != 3) throw new IllegalArgumentException("Improper date.");
    try
    {
      year = Integer.parseInt(date[0]);
      month = Integer.parseInt(date[1]);
      day = Integer.parseInt(date[2]);
    }
    catch (NumberFormatException nfe)
    {
      throw new IllegalArgumentException("Non-numeric date element.");
    }
  }

  public String getName()
  {
    return name;
  }

  public double getLatitude()
  {
    return latitude;
  }

  public double getLongitude()
  {
    return longitude;
  }

  public double getElevation()
  {
    return elevation;
  }

  public int getDay()
  {
    return day;
  }

  public int getMonth()
  {
    return month;
  }

  public int getYear()
  {
    return year;
  }

  public double getMax()
  {
    return max;
  }

  public double getMin()
  {
    return min;
  }

  public String getStation()
  {
    return station;
  }
  
  /**
   * Construct a TemperatureObservation object from a String representation.
   * 
   * @param line The String representation
   * @return The resulting TemperatureObservation
   * @throws IllegalArgumentException if there is a problem
   */
  public static TemperatureObservation parseTemperatureObservation(String line)
    throws IllegalArgumentException
  {
    TemperatureObservation result = new TemperatureObservation();
    result.fromString(line);
    return result;
  }

}
